@@ -61,7 +61,7 @@ class Client:
             method_to_api_mapping={},
             partition="aws",
         )
-        self.exceptions = MagicMock()
+        self.exceptions = MagicMock(ClientError=lobotomy.ClientError)
         self._registered_exceptions = {}
         for name in self._service.exceptions:
             new_type = type(name, (lobotomy.ClientError,), {})
@@ -107,7 +107,12 @@ class Client:
                 response["Error"]["Code"],
                 lobotomy.ClientError,
             )()
-            raise error.populate(**response["Error"])
+            raise error.populate(
+                operation_name=(
+                    called_method_name.replace("_", " ").title().replace(" ", "")
+                ),
+                **response["Error"],
+            )
         return response
 
     def __getattr__(self, item: str):
